# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## [In Progress](https://github.com/iamogbz/nvshim/pulls)

See open [issues](https://github.com/iamogbz/nvshim/issues)

## [Unreleased](https://github.com/iamogbz/nvshim/releases)

See closed [issues](https://github.com/iamogbz/nvshim/pulls?q=is%3Apr+is%3Amerged+sort%3Acreated-desc+-label%3Areleased)

## [1.1.2](https://github.com/iamogbz/nvshim/compare/v1.1.1...v1.1.2) (2022-03-25)


### Bug Fixes

* version multi-step alias resolution ([#173](https://github.com/iamogbz/nvshim/issues/173)) ([5876047](https://github.com/iamogbz/nvshim/commit/587604798c98569f1a5ca4b6ce7a008c8f88805c))

## [1.1.1](https://github.com/iamogbz/nvshim/compare/v1.1.0...v1.1.1) (2022-02-23)


### Bug Fixes

* using version message bin path ([848ad42](https://github.com/iamogbz/nvshim/commit/848ad42fe757406b0f548914993e50c263b1500f))

# [1.1.0](https://github.com/iamogbz/nvshim/compare/v1.0.5...v1.1.0) (2022-02-22)


### Features

* add nvm shim for running nvm commands ([#168](https://github.com/iamogbz/nvshim/issues/168)) ([4015efd](https://github.com/iamogbz/nvshim/commit/4015efdda7ee00c70ad47b8b58ebfe251f7ed981))

## [1.0.5](https://github.com/iamogbz/nvshim/compare/v1.0.4...v1.0.5) (2020-04-07)


### Bug Fixes

* handle process interruption gracefully ([#73](https://github.com/iamogbz/nvshim/issues/73)) ([3237c96](https://github.com/iamogbz/nvshim/commit/3237c965b15b684c7ca813db4c94aa1ed557514d))
